pub struct AcceleratorProbe {
pub backend: AcceleratorBackend,
pub compiled: bool,
pub available: bool,
pub selected: bool,
pub message: String,
}Fields
backend: AcceleratorBackendcompiled: boolavailable: boolselected: boolmessage: StringTrait Implementations
Sourceimpl Clone for AcceleratorProbe
impl Clone for AcceleratorProbe
Sourcefn clone(&self) -> AcceleratorProbe
fn clone(&self) -> AcceleratorProbe
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AcceleratorProbe
impl Debug for AcceleratorProbe
Sourceimpl<'de> Deserialize<'de> for AcceleratorProbe
impl<'de> Deserialize<'de> for AcceleratorProbe
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AcceleratorProbe
Sourceimpl JsonSchema for AcceleratorProbe
impl JsonSchema for AcceleratorProbe
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AcceleratorProbe
impl PartialEq for AcceleratorProbe
Sourcefn eq(&self, other: &AcceleratorProbe) -> bool
fn eq(&self, other: &AcceleratorProbe) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AcceleratorProbe
impl Serialize for AcceleratorProbe
impl StructuralPartialEq for AcceleratorProbe