pub struct CapabilityDescriptor {
pub name: String,
pub description: String,
pub module: String,
pub safety: SafetyClass,
pub input_schema: Value,
pub output_schema: Value,
}Fields
name: Stringdescription: Stringmodule: Stringsafety: SafetyClassinput_schema: Valueoutput_schema: ValueTrait Implementations
Sourceimpl Clone for CapabilityDescriptor
impl Clone for CapabilityDescriptor
Sourcefn clone(&self) -> CapabilityDescriptor
fn clone(&self) -> CapabilityDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CapabilityDescriptor
impl Debug for CapabilityDescriptor
Sourceimpl<'de> Deserialize<'de> for CapabilityDescriptor
impl<'de> Deserialize<'de> for CapabilityDescriptor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CapabilityDescriptor
impl JsonSchema for CapabilityDescriptor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CapabilityDescriptor
impl PartialEq for CapabilityDescriptor
Sourcefn eq(&self, other: &CapabilityDescriptor) -> bool
fn eq(&self, other: &CapabilityDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CapabilityDescriptor
impl Serialize for CapabilityDescriptor
impl StructuralPartialEq for CapabilityDescriptor