pub struct ModuleHealth {
pub ok: bool,
pub state: ModuleState,
pub message: Option<String>,
}Fields
ok: boolstate: ModuleStatemessage: Option<String>Trait Implementations
Sourceimpl Clone for ModuleHealth
impl Clone for ModuleHealth
Sourcefn clone(&self) -> ModuleHealth
fn clone(&self) -> ModuleHealth
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleHealth
impl Debug for ModuleHealth
Sourceimpl<'de> Deserialize<'de> for ModuleHealth
impl<'de> Deserialize<'de> for ModuleHealth
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleHealth
Sourceimpl JsonSchema for ModuleHealth
impl JsonSchema for ModuleHealth
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleHealth
impl PartialEq for ModuleHealth
Sourcefn eq(&self, other: &ModuleHealth) -> bool
fn eq(&self, other: &ModuleHealth) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ModuleHealth
impl Serialize for ModuleHealth
impl StructuralPartialEq for ModuleHealth