pub struct ModuleInfo {
pub id: usize,
pub name: String,
pub module_type: String,
pub state: ModuleState,
pub health: ModuleHealth,
pub dependencies: Vec<String>,
pub inputs: Vec<StreamDescriptor>,
pub outputs: Vec<StreamDescriptor>,
pub capabilities: Vec<String>,
pub physical: bool,
pub required: bool,
}Fields
id: usizename: Stringmodule_type: Stringstate: ModuleStatehealth: ModuleHealthdependencies: Vec<String>inputs: Vec<StreamDescriptor>outputs: Vec<StreamDescriptor>capabilities: Vec<String>physical: boolrequired: boolTrait Implementations
Sourceimpl Clone for ModuleInfo
impl Clone for ModuleInfo
Sourcefn clone(&self) -> ModuleInfo
fn clone(&self) -> ModuleInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleInfo
impl Debug for ModuleInfo
Sourceimpl<'de> Deserialize<'de> for ModuleInfo
impl<'de> Deserialize<'de> for ModuleInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleInfo
Sourceimpl JsonSchema for ModuleInfo
impl JsonSchema for ModuleInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleInfo
impl PartialEq for ModuleInfo
Sourcefn eq(&self, other: &ModuleInfo) -> bool
fn eq(&self, other: &ModuleInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ModuleInfo
impl Serialize for ModuleInfo
impl StructuralPartialEq for ModuleInfo