pub struct StreamDescriptor {
pub name: String,
pub direction: StreamDirection,
pub message_type: String,
pub transport: String,
}Fields
name: Stringdirection: StreamDirectionmessage_type: Stringtransport: StringTrait Implementations
Sourceimpl Clone for StreamDescriptor
impl Clone for StreamDescriptor
Sourcefn clone(&self) -> StreamDescriptor
fn clone(&self) -> StreamDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StreamDescriptor
impl Debug for StreamDescriptor
Sourceimpl<'de> Deserialize<'de> for StreamDescriptor
impl<'de> Deserialize<'de> for StreamDescriptor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for StreamDescriptor
Sourceimpl JsonSchema for StreamDescriptor
impl JsonSchema for StreamDescriptor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StreamDescriptor
impl PartialEq for StreamDescriptor
Sourcefn eq(&self, other: &StreamDescriptor) -> bool
fn eq(&self, other: &StreamDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StreamDescriptor
impl Serialize for StreamDescriptor
impl StructuralPartialEq for StreamDescriptor