pub struct StackModule {
pub name: String,
pub module_type: String,
pub required: bool,
pub physical: bool,
}Fields
name: Stringmodule_type: Stringrequired: boolphysical: boolTrait Implementations
Sourceimpl Clone for StackModule
impl Clone for StackModule
Sourcefn clone(&self) -> StackModule
fn clone(&self) -> StackModule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StackModule
impl Debug for StackModule
Sourceimpl<'de> Deserialize<'de> for StackModule
impl<'de> Deserialize<'de> for StackModule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for StackModule
Sourceimpl JsonSchema for StackModule
impl JsonSchema for StackModule
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StackModule
impl PartialEq for StackModule
Sourcefn eq(&self, other: &StackModule) -> bool
fn eq(&self, other: &StackModule) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StackModule
impl Serialize for StackModule
impl StructuralPartialEq for StackModule