pub struct TransportBinding {
pub kind: StackTransport,
pub listen: Option<SocketAddr>,
}Fields
kind: StackTransportlisten: Option<SocketAddr>Trait Implementations
Sourceimpl Clone for TransportBinding
impl Clone for TransportBinding
Sourcefn clone(&self) -> TransportBinding
fn clone(&self) -> TransportBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransportBinding
impl Debug for TransportBinding
Sourceimpl<'de> Deserialize<'de> for TransportBinding
impl<'de> Deserialize<'de> for TransportBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TransportBinding
Sourceimpl JsonSchema for TransportBinding
impl JsonSchema for TransportBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TransportBinding
impl PartialEq for TransportBinding
Sourcefn eq(&self, other: &TransportBinding) -> bool
fn eq(&self, other: &TransportBinding) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TransportBinding
impl Serialize for TransportBinding
impl StructuralPartialEq for TransportBinding