pub struct AgentModelResponse {
pub ok: bool,
pub provider: String,
pub model: String,
pub prompt: String,
pub text: String,
}Fields
ok: boolprovider: Stringmodel: Stringprompt: Stringtext: StringTrait Implementations
Sourceimpl Clone for AgentModelResponse
impl Clone for AgentModelResponse
Sourcefn clone(&self) -> AgentModelResponse
fn clone(&self) -> AgentModelResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentModelResponse
impl Debug for AgentModelResponse
Sourceimpl<'de> Deserialize<'de> for AgentModelResponse
impl<'de> Deserialize<'de> for AgentModelResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AgentModelResponse
Sourceimpl JsonSchema for AgentModelResponse
impl JsonSchema for AgentModelResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AgentModelResponse
impl PartialEq for AgentModelResponse
Sourcefn eq(&self, other: &AgentModelResponse) -> bool
fn eq(&self, other: &AgentModelResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AgentModelResponse
impl Serialize for AgentModelResponse
impl StructuralPartialEq for AgentModelResponse