pub struct CameraStatus {
pub status: String,
pub health: String,
pub stream_url: Option<String>,
pub snapshot_url: Option<String>,
}Fields
status: Stringhealth: Stringstream_url: Option<String>snapshot_url: Option<String>Trait Implementations
Sourceimpl Clone for CameraStatus
impl Clone for CameraStatus
Sourcefn clone(&self) -> CameraStatus
fn clone(&self) -> CameraStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CameraStatus
impl Debug for CameraStatus
Sourceimpl<'de> Deserialize<'de> for CameraStatus
impl<'de> Deserialize<'de> for CameraStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CameraStatus
impl JsonSchema for CameraStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CameraStatus
impl RefUnwindSafe for CameraStatus
impl Send for CameraStatus
impl Sync for CameraStatus
impl Unpin for CameraStatus
impl UnsafeUnpin for CameraStatus
impl UnwindSafe for CameraStatus