pub struct CaptureResult {
pub ok: bool,
pub source: String,
pub content_type: String,
pub byte_len: usize,
pub captured_at_ms: u128,
pub sha256: String,
}Fields
ok: boolsource: Stringcontent_type: Stringbyte_len: usizecaptured_at_ms: u128sha256: StringTrait Implementations
Sourceimpl Clone for CaptureResult
impl Clone for CaptureResult
Sourcefn clone(&self) -> CaptureResult
fn clone(&self) -> CaptureResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaptureResult
impl Debug for CaptureResult
Sourceimpl<'de> Deserialize<'de> for CaptureResult
impl<'de> Deserialize<'de> for CaptureResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CaptureResult
impl JsonSchema for CaptureResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CaptureResult
impl RefUnwindSafe for CaptureResult
impl Send for CaptureResult
impl Sync for CaptureResult
impl Unpin for CaptureResult
impl UnsafeUnpin for CaptureResult
impl UnwindSafe for CaptureResult