pub struct CommandOverlay {
pub left_cmd: f64,
pub right_cmd: f64,
pub speed_mode: SpeedMode,
pub max_speed: f64,
pub estop: bool,
}Fields
left_cmd: f64right_cmd: f64speed_mode: SpeedModemax_speed: f64estop: boolTrait Implementations
Sourceimpl Clone for CommandOverlay
impl Clone for CommandOverlay
Sourcefn clone(&self) -> CommandOverlay
fn clone(&self) -> CommandOverlay
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandOverlay
impl Debug for CommandOverlay
Sourceimpl Default for CommandOverlay
impl Default for CommandOverlay
Sourcefn default() -> CommandOverlay
fn default() -> CommandOverlay
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CommandOverlay
impl<'de> Deserialize<'de> for CommandOverlay
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommandOverlay
impl JsonSchema for CommandOverlay
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CommandOverlay
impl PartialEq for CommandOverlay
Sourcefn eq(&self, other: &CommandOverlay) -> bool
fn eq(&self, other: &CommandOverlay) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CommandOverlay
impl Serialize for CommandOverlay
impl StructuralPartialEq for CommandOverlay