pub struct CommandStreamState {
pub left_cmd: f64,
pub right_cmd: f64,
pub session_id: Option<String>,
pub speed_mode: SpeedMode,
pub max_speed: f64,
}Fields
left_cmd: f64right_cmd: f64session_id: Option<String>speed_mode: SpeedModemax_speed: f64Trait Implementations
Sourceimpl Clone for CommandStreamState
impl Clone for CommandStreamState
Sourcefn clone(&self) -> CommandStreamState
fn clone(&self) -> CommandStreamState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandStreamState
impl Debug for CommandStreamState
Sourceimpl<'de> Deserialize<'de> for CommandStreamState
impl<'de> Deserialize<'de> for CommandStreamState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommandStreamState
impl JsonSchema for CommandStreamState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandStreamState
impl RefUnwindSafe for CommandStreamState
impl Send for CommandStreamState
impl Sync for CommandStreamState
impl Unpin for CommandStreamState
impl UnsafeUnpin for CommandStreamState
impl UnwindSafe for CommandStreamState