pub struct DetectionFrame {
pub frame_id: String,
pub id: String,
pub label: String,
pub confidence: f64,
pub x_m: f64,
pub y_m: f64,
pub width_m: f64,
pub height_m: f64,
}Fields
frame_id: Stringid: Stringlabel: Stringconfidence: f64x_m: f64y_m: f64width_m: f64height_m: f64Trait Implementations
Sourceimpl Clone for DetectionFrame
impl Clone for DetectionFrame
Sourcefn clone(&self) -> DetectionFrame
fn clone(&self) -> DetectionFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DetectionFrame
impl Debug for DetectionFrame
Sourceimpl Default for DetectionFrame
impl Default for DetectionFrame
Sourcefn default() -> DetectionFrame
fn default() -> DetectionFrame
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DetectionFrame
impl<'de> Deserialize<'de> for DetectionFrame
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DetectionFrame
impl JsonSchema for DetectionFrame
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DetectionFrame
impl PartialEq for DetectionFrame
Sourcefn eq(&self, other: &DetectionFrame) -> bool
fn eq(&self, other: &DetectionFrame) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DetectionFrame
impl Serialize for DetectionFrame
impl StructuralPartialEq for DetectionFrame