pub struct OccupancyGridFrame {
pub frame_id: String,
pub width: u32,
pub height: u32,
pub resolution_m: f64,
pub origin: Pose2d,
pub cells: Vec<i8>,
}Fields
frame_id: Stringwidth: u32height: u32resolution_m: f64origin: Pose2dcells: Vec<i8>Trait Implementations
Sourceimpl Clone for OccupancyGridFrame
impl Clone for OccupancyGridFrame
Sourcefn clone(&self) -> OccupancyGridFrame
fn clone(&self) -> OccupancyGridFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OccupancyGridFrame
impl Debug for OccupancyGridFrame
Sourceimpl Default for OccupancyGridFrame
impl Default for OccupancyGridFrame
Sourcefn default() -> OccupancyGridFrame
fn default() -> OccupancyGridFrame
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OccupancyGridFrame
impl<'de> Deserialize<'de> for OccupancyGridFrame
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OccupancyGridFrame
impl JsonSchema for OccupancyGridFrame
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OccupancyGridFrame
impl PartialEq for OccupancyGridFrame
Sourcefn eq(&self, other: &OccupancyGridFrame) -> bool
fn eq(&self, other: &OccupancyGridFrame) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OccupancyGridFrame
impl Serialize for OccupancyGridFrame
impl StructuralPartialEq for OccupancyGridFrame