pub struct OdometryStatus {
pub status: String,
pub left_m: Option<f64>,
pub right_m: Option<f64>,
}Fields
status: Stringleft_m: Option<f64>right_m: Option<f64>Trait Implementations
Sourceimpl Clone for OdometryStatus
impl Clone for OdometryStatus
Sourcefn clone(&self) -> OdometryStatus
fn clone(&self) -> OdometryStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OdometryStatus
impl Debug for OdometryStatus
Sourceimpl<'de> Deserialize<'de> for OdometryStatus
impl<'de> Deserialize<'de> for OdometryStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OdometryStatus
impl JsonSchema for OdometryStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OdometryStatus
impl RefUnwindSafe for OdometryStatus
impl Send for OdometryStatus
impl Sync for OdometryStatus
impl Unpin for OdometryStatus
impl UnsafeUnpin for OdometryStatus
impl UnwindSafe for OdometryStatus