pub struct RawFrameStatus {
pub status: String,
pub source: String,
pub last_ms: Option<u128>,
}Fields
status: Stringsource: Stringlast_ms: Option<u128>Trait Implementations
Sourceimpl Clone for RawFrameStatus
impl Clone for RawFrameStatus
Sourcefn clone(&self) -> RawFrameStatus
fn clone(&self) -> RawFrameStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RawFrameStatus
impl Debug for RawFrameStatus
Sourceimpl<'de> Deserialize<'de> for RawFrameStatus
impl<'de> Deserialize<'de> for RawFrameStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RawFrameStatus
impl JsonSchema for RawFrameStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RawFrameStatus
impl RefUnwindSafe for RawFrameStatus
impl Send for RawFrameStatus
impl Sync for RawFrameStatus
impl Unpin for RawFrameStatus
impl UnsafeUnpin for RawFrameStatus
impl UnwindSafe for RawFrameStatus