pub struct ResourceSample {
pub sampled_at_ms: u128,
pub process_id: u32,
pub cpu_time_ticks: Option<u64>,
pub memory_rss_bytes: Option<u64>,
}Fields
sampled_at_ms: u128process_id: u32cpu_time_ticks: Option<u64>memory_rss_bytes: Option<u64>Trait Implementations
Sourceimpl Clone for ResourceSample
impl Clone for ResourceSample
Sourcefn clone(&self) -> ResourceSample
fn clone(&self) -> ResourceSample
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceSample
impl Debug for ResourceSample
Sourceimpl<'de> Deserialize<'de> for ResourceSample
impl<'de> Deserialize<'de> for ResourceSample
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResourceSample
impl JsonSchema for ResourceSample
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResourceSample
impl RefUnwindSafe for ResourceSample
impl Send for ResourceSample
impl Sync for ResourceSample
impl Unpin for ResourceSample
impl UnsafeUnpin for ResourceSample
impl UnwindSafe for ResourceSample