pub struct RunLogEntry {
pub timestamp: u128,
pub run_id: String,
pub module: String,
pub event: String,
pub level: String,
pub fields: BTreeMap<String, Value>,
}Fields
timestamp: u128run_id: Stringmodule: Stringevent: Stringlevel: Stringfields: BTreeMap<String, Value>Trait Implementations
Sourceimpl Clone for RunLogEntry
impl Clone for RunLogEntry
Sourcefn clone(&self) -> RunLogEntry
fn clone(&self) -> RunLogEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunLogEntry
impl Debug for RunLogEntry
Sourceimpl<'de> Deserialize<'de> for RunLogEntry
impl<'de> Deserialize<'de> for RunLogEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunLogEntry
impl JsonSchema for RunLogEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunLogEntry
impl RefUnwindSafe for RunLogEntry
impl Send for RunLogEntry
impl Sync for RunLogEntry
impl Unpin for RunLogEntry
impl UnsafeUnpin for RunLogEntry
impl UnwindSafe for RunLogEntry