pub struct SensorSnapshot {
pub battery: BatteryStatus,
pub odometry: OdometryStatus,
pub camera: CameraStatus,
pub raw_frame: RawFrameStatus,
}Fields
battery: BatteryStatusodometry: OdometryStatuscamera: CameraStatusraw_frame: RawFrameStatusTrait Implementations
Sourceimpl Clone for SensorSnapshot
impl Clone for SensorSnapshot
Sourcefn clone(&self) -> SensorSnapshot
fn clone(&self) -> SensorSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SensorSnapshot
impl Debug for SensorSnapshot
Sourceimpl<'de> Deserialize<'de> for SensorSnapshot
impl<'de> Deserialize<'de> for SensorSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SensorSnapshot
impl JsonSchema for SensorSnapshot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SensorSnapshot
impl RefUnwindSafe for SensorSnapshot
impl Send for SensorSnapshot
impl Sync for SensorSnapshot
impl Unpin for SensorSnapshot
impl UnsafeUnpin for SensorSnapshot
impl UnwindSafe for SensorSnapshot