pub struct TelemetryFrame {Show 19 fields
pub ts_ms: u128,
pub robot: String,
pub profile: String,
pub battery_v: Option<f64>,
pub left_cmd: f64,
pub right_cmd: f64,
pub odometry_left: Option<f64>,
pub odometry_right: Option<f64>,
pub session_id: Option<String>,
pub deadman_ok: bool,
pub estop: bool,
pub stopped_by_deadman: bool,
pub soft_odometry_limited: bool,
pub soft_odometry_limit_m: f64,
pub speed_mode: SpeedMode,
pub max_speed: f64,
pub sensors: SensorSnapshot,
pub resource: Option<ResourceSample>,
pub source: String,
}Fields
ts_ms: u128robot: Stringprofile: Stringbattery_v: Option<f64>left_cmd: f64right_cmd: f64odometry_left: Option<f64>odometry_right: Option<f64>session_id: Option<String>deadman_ok: boolestop: boolstopped_by_deadman: boolsoft_odometry_limited: boolsoft_odometry_limit_m: f64speed_mode: SpeedModemax_speed: f64sensors: SensorSnapshotresource: Option<ResourceSample>source: StringTrait Implementations
Sourceimpl Clone for TelemetryFrame
impl Clone for TelemetryFrame
Sourcefn clone(&self) -> TelemetryFrame
fn clone(&self) -> TelemetryFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TelemetryFrame
impl Debug for TelemetryFrame
Sourceimpl<'de> Deserialize<'de> for TelemetryFrame
impl<'de> Deserialize<'de> for TelemetryFrame
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TelemetryFrame
impl JsonSchema for TelemetryFrame
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TelemetryFrame
impl RefUnwindSafe for TelemetryFrame
impl Send for TelemetryFrame
impl Sync for TelemetryFrame
impl Unpin for TelemetryFrame
impl UnsafeUnpin for TelemetryFrame
impl UnwindSafe for TelemetryFrame