pub struct TelemetryStreamFrame {
pub kind: String,
pub ts_ms: u128,
pub telemetry: TelemetryFrame,
pub health: Health,
pub command: CommandStreamState,
pub safety: SafetyStreamState,
pub visualization: VisualizationFrame,
}Fields
kind: Stringts_ms: u128telemetry: TelemetryFramehealth: Healthcommand: CommandStreamStatesafety: SafetyStreamStatevisualization: VisualizationFrameTrait Implementations
Sourceimpl Clone for TelemetryStreamFrame
impl Clone for TelemetryStreamFrame
Sourcefn clone(&self) -> TelemetryStreamFrame
fn clone(&self) -> TelemetryStreamFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TelemetryStreamFrame
impl Debug for TelemetryStreamFrame
Sourceimpl<'de> Deserialize<'de> for TelemetryStreamFrame
impl<'de> Deserialize<'de> for TelemetryStreamFrame
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TelemetryStreamFrame
impl JsonSchema for TelemetryStreamFrame
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TelemetryStreamFrame
impl RefUnwindSafe for TelemetryStreamFrame
impl Send for TelemetryStreamFrame
impl Sync for TelemetryStreamFrame
impl Unpin for TelemetryStreamFrame
impl UnsafeUnpin for TelemetryStreamFrame
impl UnwindSafe for TelemetryStreamFrame