pub struct VisualizationPath {
pub frame_id: String,
pub poses: Vec<Pose2d>,
}Fields
frame_id: Stringposes: Vec<Pose2d>Trait Implementations
Sourceimpl Clone for VisualizationPath
impl Clone for VisualizationPath
Sourcefn clone(&self) -> VisualizationPath
fn clone(&self) -> VisualizationPath
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VisualizationPath
impl Debug for VisualizationPath
Sourceimpl Default for VisualizationPath
impl Default for VisualizationPath
Sourcefn default() -> VisualizationPath
fn default() -> VisualizationPath
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for VisualizationPath
impl<'de> Deserialize<'de> for VisualizationPath
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VisualizationPath
impl JsonSchema for VisualizationPath
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VisualizationPath
impl PartialEq for VisualizationPath
Sourcefn eq(&self, other: &VisualizationPath) -> bool
fn eq(&self, other: &VisualizationPath) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VisualizationPath
impl Serialize for VisualizationPath
impl StructuralPartialEq for VisualizationPath